==> jc-1.4.0.tar.gz: soot/jimple/parser/node/ANullBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ANullBaseTypeNoName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class bece02da73f316ae soot_jimple_parser_node_ANullBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ANullBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ANullBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNullType$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$_init$de7b4356e0506287(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TNullType$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);
extern struct _jc_soot_jimple_parser_node_TNullType$object *_jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$getNullType$b7414e20688fb682(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$setNullType$3f34deec3b3ca0db(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TNullType$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$getNullType$b7414e20688fb682;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$setNullType$3f34deec3b3ca0db;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);
	struct _jc_soot_jimple_parser_node_TNullType$object	*(*getNullType$b7414e20688fb682)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setNullType$3f34deec3b3ca0db)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TNullType$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods	soot_jimple_parser_node_ANullBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TNullType$object	*__5fnullType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs	soot_jimple_parser_node_ANullBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ANullBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ANullBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANullBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANullBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANullBaseTypeNoName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/ANullBaseTypeNoName.h <==
// public final class soot.jimple.parser.node.ANullBaseTypeNoName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bece02da73f316ae soot_jimple_parser_node_ANullBaseTypeNoName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class cf55e2dd32eddb45 soot_jimple_parser_node_PBaseTypeNoName

// header file dependencies
// @dep_header soot_jimple_parser_node_PBaseTypeNoName

#include "soot/jimple/parser/node/PBaseTypeNoName.h"

#ifndef _JC_soot_jimple_parser_node_ANullBaseTypeNoName_H_
#define _JC_soot_jimple_parser_node_ANullBaseTypeNoName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TNullType$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$object;

typedef const struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable;
typedef const struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$_init$de7b4356e0506287(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TNullType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TNullType$object *_jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$getNullType$b7414e20688fb682(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$setNullType$3f34deec3b3ca0db(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TNullType$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_ANullBaseTypeNoName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$getNullType$b7414e20688fb682;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$setNullType$3f34deec3b3ca0db;
extern _jc_method _jc_soot_jimple_parser_node_ANullBaseTypeNoName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TNullType$object	*(*getNullType$b7414e20688fb682)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setNullType$3f34deec3b3ca0db)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *, struct _jc_soot_jimple_parser_node_TNullType$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PBaseTypeNoName$vmethods	soot_jimple_parser_node_PBaseTypeNoName;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vmethods	soot_jimple_parser_node_ANullBaseTypeNoName;
};

// Vtype
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs {
	struct _jc_soot_jimple_parser_node_TNullType$object	*__5fnullType__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs {
    _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_refs	soot_jimple_parser_node_ANullBaseTypeNoName;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_refs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_PBaseTypeNoName;
    _jc_soot_jimple_parser_node_ANullBaseTypeNoName$sub_nonrefs	soot_jimple_parser_node_ANullBaseTypeNoName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_ANullBaseTypeNoName$object {
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype	*vtype;
	_jc_soot_jimple_parser_node_ANullBaseTypeNoName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_ANullBaseTypeNoName$vtype _jc_soot_jimple_parser_node_ANullBaseTypeNoName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_ANullBaseTypeNoName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_ANullBaseTypeNoName$class_object;

#endif	/* _JC_soot_jimple_parser_node_ANullBaseTypeNoName_H_ */
